@@ -223,7 +223,10 @@ class DBConnect:
                 '$limit': int, '$offset': int, '$orderby': str, '$start_date': str, '$date_type': str,
                 '$end_date': str,
             },
-            optional={'$start_date': '', '$end_date': '', '$date_type': 'update_time', '$offset': 0, '$limit': 10, '$orderby': ''})
+            optional={'$start_date': '', '$end_date': '', '$date_type': 'update_time',
+                      '$offset': 0, '$limit': 10, '$orderby': ''},
+            allow_extra=True
+        )
         try:
             limit = int(param['$limit'])  # 指示页大小（从1开始）
             offset = int(param['$offset'])  # 指示记录起始位置（从0开始）
