@@ -40,9 +40,10 @@ def set_token_session(app, verify, per_defaults: list, whitelist: list = []):
 
 
 class VerifyToken:
-    def __init__(self, per_defaults=[{}], debug: bool = False, debug_permission: list = [0, 1, 2, 4, 8, 16, 32]):
+    def __init__(self, per_defaults=[{}], debug: bool = False, debug_permission: list = [0, 1, 2, 4, 8, 16, 32], proxy_none_response: bool = True):
         self.debug = debug  # 是否开启DEBUG模式
         self.debug_permission = debug_permission
+        self.proxy_none_response = proxy_none_response  # 代理无权限响应
         self.uid = ''
         # 认证中心的 Redis 库号码
         self.redis_db_permission = os.environ.get('REDIS_DB_PERMISSION', None)
@@ -203,12 +204,13 @@ class VerifyToken:
         else:
             is_all_data = False  # 安全考虑，含False都为False
         # 结束合并角色权限
-        if ([0] == permission_list) or (not permission_list):
-            handle_abnormal(
-                message='无 "{0}-{1}" 的访问权限({2})'.format(
-                    center_name, permission_name, str(permission_list)),
-                status=403,
-            )
+        if self.proxy_none_response:
+            if ([0] == permission_list) or (not permission_list):
+                handle_abnormal(
+                    message='无 "{0}-{1}" 的访问权限({2})'.format(
+                        center_name, permission_name, str(permission_list)),
+                    status=403,
+                )
         permission_status = {
             'permission_list': permission_list, 'is_all_data': is_all_data}
         return permission_status
